@@ -75,6 +75,11 @@ import zipfile
 
 # noinspection PyPackageRequirements
 import bs4  # pip install beautifulsoup4
+# noinspection PyPackageRequirements
+import prettytable  # pip install PrettyTable
+import semver
+# import texttable  # ... can't deal with Unicode properly
+
 try:
     # noinspection PyPackageRequirements
     import docx  # pip install python-docx (NOT docx) - BUT python-docx requires lxml which has C dependencies  # noqa
@@ -94,10 +99,12 @@ except ImportError:
     DOCX_TABLE_TYPE = "CustomDocxTable"
     DOCX_CONTAINER_TYPE = None
     DOCX_BLOCK_ITEM_TYPE = None
+
 try:
     import docx2txt  # pip install docx2txt
 except ImportError:
     docx2txt = None
+
 try:
     # noinspection PyPackageRequirements
     import pdfminer  # pip install pdfminer
@@ -111,8 +118,7 @@ try:
     import pdfminer.pdfpage
 except ImportError:
     pdfminer = None
-# noinspection PyPackageRequirements
-import prettytable  # pip install PrettyTable
+
 try:
     # noinspection PyPackageRequirements
     import pyth  # pip install pyth (PYTHON 2 ONLY; https://pypi.python.org/pypi/pyth/0.5.4)  # noqa
@@ -122,7 +128,6 @@ try:
     import pyth.plugins.plaintext.writer
 except ImportError:
     pyth = None
-# import texttable  # ... can't deal with Unicode properly
 
 import logging
 log = logging.getLogger(__name__)
@@ -151,6 +156,33 @@ tools = {
 }
 
 
+def does_unrtf_support_quiet() -> bool:
+    """
+    The unrtf tool supports the '--quiet' argument from version XXX.
+    """
+    required_unrtf_version = (0, 21, 9)
+    # ... probably: http://hg.savannah.gnu.org/hgweb/unrtf/
+    # ... 0.21.9 definitely supports --quiet
+    # ... 0.19.3 definitely doesn't support it
+    unrtf_filename = shutil.which('unrtf')
+    if not unrtf_filename:
+        return False
+    p = subprocess.Popen(["unrtf", "--version"],
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE)
+    _, err_bytes = p.communicate()
+    text = err_bytes.decode(sys.getdefaultencoding())
+    lines = text.split()
+    if len(lines) < 1:
+        return False
+    version_str = lines[0]
+    unrtf_version = semver.parse_version_info(version_str)
+    return unrtf_version >= required_unrtf_version
+
+
+UNRTF_SUPPORTS_QUIET = does_unrtf_support_quiet()
+
+
 def update_external_tools(tooldict):
     global tools
     tools.update(tooldict)
@@ -452,7 +484,7 @@ def docx_process_table(table: DOCX_TABLE_TYPE,
 
     """
 
-    def get_cell_text(cell_):
+    def get_cell_text(cell_) -> str:
         cellparagraphs = [paragraph.text.strip()
                           for paragraph in cell_.paragraphs]
         cellparagraphs = [x for x in cellparagraphs if x]
@@ -488,7 +520,7 @@ def docx_process_table(table: DOCX_TABLE_TYPE,
     else:
         # noinspection PyTypeChecker
         for row in table.rows:
-            ptrow = []
+            ptrow = []  # type: List[str]
             # noinspection PyTypeChecker
             for cell in row.cells:
                 ptrow.append(get_cell_text(cell))
@@ -652,7 +684,7 @@ def convert_odt_to_text(filename: str = None,
         z = zipfile.ZipFile(fp)
         tree = ElementTree.fromstring(z.read('content.xml'))
         # ... may raise zipfile.BadZipfile
-        textlist = []
+        textlist = []  # type: List[str]
         for element in tree.iter():
             if element.text:
                 textlist.append(element.text.strip())
@@ -695,12 +727,14 @@ def convert_rtf_to_text(filename: str = None,
                         **kwargs) -> str:
     unrtf = tools['unrtf']
     if unrtf:  # Best
+        args = [unrtf, '--text', '--nopict']
+        if UNRTF_SUPPORTS_QUIET:
+            args.append('--quiet')
         if filename:
-            return get_cmd_output(
-                unrtf, '--text', '--nopict', '--quiet', filename)
+            args.append(filename)
+            return get_cmd_output(*args)
         else:
-            return get_cmd_output_from_stdin(
-                blob, unrtf, '--text', '--nopict', '--quiet')
+            return get_cmd_output_from_stdin(blob, *args)
     elif pyth:  # Very memory-consuming:
         # https://github.com/brendonh/pyth/blob/master/pyth/plugins/rtf15/reader.py  # noqa
         with get_filelikeobject(filename, blob) as fp:
